@@ -21,6 +21,7 @@ from .data_types import (
     CookieType,
     DownloadedFile,
     ElementState,
+    ForcedColors,
     GeoLocation,
     HttpCredentials,
     NewPageDetails,
@@ -28,6 +29,7 @@ from .data_types import (
     Proxy,
     RecordHar,
     RecordVideo,
+    ReduceMotion,
     RequestMethod,
     SelectAttribute,
     SelectionType,
