@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from enum import Enum, auto
+from enum import Enum, IntFlag, auto
 from typing import Dict, Union
 
 from typing_extensions import TypedDict
@@ -463,7 +463,7 @@ class AutoClosingLevel(Enum):
     MANUAL = auto()
 
 
-class ElementState(Enum):
+class ElementState(IntFlag):
     """Enum that defines the state an element can have.
 
     The following ``states`` are possible:
@@ -485,37 +485,26 @@ class ElementState(Enum):
     | ``stable``     | to be both ``visible`` and ``stable``. |
     """
 
-    attached = auto()
-    detached = auto()
-    visible = auto()
-    hidden = auto()
-    enabled = auto()
-    disabled = auto()
-    editable = auto()
-    readonly = auto()
-    selected = auto()
-    deselected = auto()
-    focused = auto()
-    defocused = auto()
-    checked = auto()
-    unchecked = auto()
-    stable = auto()
+    attached = 1
+    detached = 2
+    visible = 4
+    hidden = 8
+    enabled = 16
+    disabled = 32
+    editable = 64
+    readonly = 128
+    selected = 256
+    deselected = 512
+    focused = 1024
+    defocused = 2048
+    checked = 4096
+    unchecked = 8192
+    stable = 16384
 
 
-class ElementStateKey(Enum):
-    """Enum that defines the state an element can have directly.
-
-    See `ElementState` for explaination.
-
-    """
-
-    attached = auto()
-    visible = auto()
-    disabled = auto()
-    readonly = auto()
-    selected = auto()
-    focused = auto()
-    checked = auto()
+ElementStateKey = (
+    ElementState  # Deprecated. Remove after `Get Element State` is removed.
+)
 
 
 class ScreenshotFileTypes(Enum):
@@ -531,3 +520,17 @@ class PageLoadStates(Enum):
     load = auto()
     domcontentloaded = auto()
     networkidle = auto()
+
+
+class ReduceMotion(Enum):
+    """Emulates `prefers-reduced-motion` media feature, supported values are `reduce`, `no-preference`."""
+
+    reduce = auto()
+    no_preference = auto()
+
+
+class ForcedColors(Enum):
+    """Emulates `forced-colors` media feature, supported values are `active`, `none`."""
+
+    active = auto()
+    none = auto()
